#' @import checkmate
#' @import data.table
"_PACKAGE"
